'R' implementation of the 'vol2bird' software for generating vertical profiles of birds and other biological signals in weather radar data. See Dokter et al. (2011) tools:::Rd_expr_doi("10.1098/rsif.2010.0116") for a paper describing the methodology.
Maintainer: Adriaan M. Dokter [email protected] (ORCID) (vol2birdR author and maintainer and author of vol2bird library)
Authors:
Adriaan M. Dokter [email protected] (ORCID) (vol2birdR author and maintainer and author of vol2bird library)
Anders Henja [email protected] (vol2birdR package author and author of RAVE and HLHDF libraries)
Other contributors:
Alexander Tedeschi [email protected] (ORCID) (contributer to vol2birdR and vol2bird library) [contributor]
Tsung-Yu Lin (contributor MistNet segmentation model) [contributor]
Subranshu Maji [email protected] (contributor MistNet segmentation model) [contributor]
Daniel Sheldon [email protected] (contributor MistNet segmentation model) [contributor]
Bart Kranstauber [email protected] (ORCID) [contributor]
Jurriaan H. Spaaks (contributor to vol2bird library) [contributor]
Lourens Veen (contributor to vol2bird library) [contributor]
Iwan Holleman (contributor to vol2bird library) [contributor]
Hidde Leijnse (contributor to vol2bird library) [contributor]
John H. Merritt (author of RSL library) [contributor, copyright holder]
Bart Kelley (contributor and maintainer of RSL library) [contributor]
Mark Couture (author of iris2odim add-on to RAVE library) [contributor]
Daniel Falbel (contributor of original idea for building with torch support) [contributor]
Swedish Meteorological and Hydrological Institute, SMHI (copyright holder of HLHDF and RAVE libraries) [copyright holder]
GloBAM (https://globam.science) [funder]
To get started, see:
Dokter et al. (2016) tools:::Rd_expr_doi("https://doi.org/10.1098/rsif.2010.0116"): a paper describing the profiling algorithm.
'vol2bird' 'C' code documentation: an overview of the algorithm structure.
Lin T-Y et al. (2019) tools:::Rd_expr_doi("https://doi.org/10.1111/2041-210X.13280"): a paper describing the 'MistNet' model for rain segmentation.
Useful links: